Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/include/rpc u_int -> unsigned, u_long -> unsigned long, etc.



details:   https://anonhg.NetBSD.org/src/rev/e362645e337b
branches:  trunk
changeset: 343122:e362645e337b
user:      dholland <dholland%NetBSD.org@localhost>
date:      Sat Jan 23 01:05:30 2016 +0000

description:
u_int -> unsigned, u_long -> unsigned long, etc.

diffstat:

 include/rpc/auth.h      |   6 ++--
 include/rpc/auth_unix.h |   6 ++--
 include/rpc/clnt.h      |  39 ++++++++++++++++++-----------------
 include/rpc/clnt_soc.h  |  44 ++++++++++++++++++++--------------------
 include/rpc/pmap_clnt.h |  17 +++++++++------
 include/rpc/rpc.h       |   4 +-
 include/rpc/rpcb_prot.x |   8 +++---
 include/rpc/svc.h       |  34 +++++++++++++++---------------
 include/rpc/svc_soc.h   |  22 ++++++++++----------
 include/rpc/xdr.h       |  53 ++++++++++++++++++++++++------------------------
 10 files changed, 119 insertions(+), 114 deletions(-)

diffs (truncated from 655 to 300 lines):

diff -r 749b9b187a21 -r e362645e337b include/rpc/auth.h
--- a/include/rpc/auth.h        Sat Jan 23 00:43:42 2016 +0000
+++ b/include/rpc/auth.h        Sat Jan 23 01:05:30 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: auth.h,v 1.17 2005/12/26 19:01:47 perry Exp $  */
+/*     $NetBSD: auth.h,v 1.18 2016/01/23 01:05:30 dholland Exp $       */
 
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
@@ -87,7 +87,7 @@
 struct opaque_auth {
        enum_t  oa_flavor;              /* flavor of auth */
        caddr_t oa_base;                /* address of more auth stuff */
-       u_int   oa_length;              /* not to exceed MAX_AUTH_BYTES */
+       unsigned oa_length;             /* not to exceed MAX_AUTH_BYTES */
 };
 
 
@@ -169,7 +169,7 @@
 extern AUTH *authunix_create           (char *, int, int, int, int *);
 extern AUTH *authunix_create_default   (void);
 extern AUTH *authnone_create           (void);
-extern AUTH *authdes_create            (char *, u_int,
+extern AUTH *authdes_create            (char *, unsigned,
                                            struct sockaddr_in *, des_block *);
 extern bool_t xdr_opaque_auth          (XDR *, struct opaque_auth *);
 
diff -r 749b9b187a21 -r e362645e337b include/rpc/auth_unix.h
--- a/include/rpc/auth_unix.h   Sat Jan 23 00:43:42 2016 +0000
+++ b/include/rpc/auth_unix.h   Sat Jan 23 01:05:30 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: auth_unix.h,v 1.8 2005/02/03 04:39:32 perry Exp $      */
+/*     $NetBSD: auth_unix.h,v 1.9 2016/01/23 01:05:30 dholland Exp $   */
 
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
@@ -59,11 +59,11 @@
  * Unix style credentials.
  */
 struct authunix_parms {
-       u_long   aup_time;
+       unsigned long aup_time;
        char    *aup_machname;
        int      aup_uid;
        int      aup_gid;
-       u_int    aup_len;
+       unsigned aup_len;
        int     *aup_gids;
 };
 
diff -r 749b9b187a21 -r e362645e337b include/rpc/clnt_soc.h
--- a/include/rpc/clnt_soc.h    Sat Jan 23 00:43:42 2016 +0000
+++ b/include/rpc/clnt_soc.h    Sat Jan 23 01:05:30 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: clnt_soc.h,v 1.3 2005/02/06 04:40:51 perry Exp $       */
+/*     $NetBSD: clnt_soc.h,v 1.4 2016/01/23 01:05:30 dholland Exp $    */
 
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
@@ -55,26 +55,26 @@
  * CLIENT *
  * clnttcp_create(raddr, prog, vers, sockp, sendsz, recvsz)
  *     struct sockaddr_in *raddr;
- *     u_long prog;
- *     u_long version;
+ *     unsigned long prog;
+ *     unsigned long version;
  *     int *sockp;
- *     u_int sendsz;
- *     u_int recvsz;
+ *     unsigned sendsz;
+ *     unsigned recvsz;
  */
 __BEGIN_DECLS
 extern CLIENT *clnttcp_create(struct sockaddr_in *,
-                               u_long,
-                               u_long,
+                               unsigned long,
+                               unsigned long,
                                int *,
-                               u_int,
-                               u_int);
+                               unsigned,
+                               unsigned);
 __END_DECLS
 
 /*
  * Raw (memory) rpc.
  */
 __BEGIN_DECLS
-extern CLIENT *clntraw_create  (u_long, u_long);
+extern CLIENT *clntraw_create  (unsigned long, unsigned long);
 __END_DECLS
 
 
@@ -83,8 +83,8 @@
  * CLIENT *
  * clntudp_create(raddr, program, version, wait, sockp)
  *     struct sockaddr_in *raddr;
- *     u_long program;
- *     u_long version;
+ *     unsigned long program;
+ *     unsigned long version;
  *     struct timeval wait;
  *     int *sockp;
  *
@@ -92,26 +92,26 @@
  * CLIENT *
  * clntudp_bufcreate(raddr, program, version, wait, sockp, sendsz, recvsz)
  *     struct sockaddr_in *raddr;
- *     u_long program;
- *     u_long version;
+ *     unsigned long program;
+ *     unsigned long version;
  *     struct timeval wait;
  *     int *sockp;
- *     u_int sendsz;
- *     u_int recvsz;
+ *     unsigned sendsz;
+ *     unsigned recvsz;
  */
 __BEGIN_DECLS
 extern CLIENT *clntudp_create(struct sockaddr_in *,
-                               u_long,
-                               u_long,
+                               unsigned long,
+                               unsigned long,
                                struct timeval,
                                int *);
 extern CLIENT *clntudp_bufcreate(struct sockaddr_in *,
-                                    u_long,
-                                    u_long,
+                                    unsigned long,
+                                    unsigned long,
                                     struct timeval,
                                     int *,
-                                    u_int,
-                                    u_int);
+                                    unsigned,
+                                    unsigned);
 __END_DECLS
 
 #endif /* _RPC_CLNT_SOC_H */
diff -r 749b9b187a21 -r e362645e337b include/rpc/pmap_clnt.h
--- a/include/rpc/pmap_clnt.h   Sat Jan 23 00:43:42 2016 +0000
+++ b/include/rpc/pmap_clnt.h   Sat Jan 23 01:05:30 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pmap_clnt.h,v 1.11 2009/01/11 03:04:12 christos Exp $  */
+/*     $NetBSD: pmap_clnt.h,v 1.12 2016/01/23 01:05:30 dholland Exp $  */
 
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
@@ -66,23 +66,26 @@
 #include <sys/cdefs.h>
 
 __BEGIN_DECLS
-extern bool_t          pmap_set(u_long, u_long, int, int);
-extern bool_t          pmap_unset(u_long, u_long);
+extern bool_t          pmap_set(unsigned long, unsigned long, int, int);
+extern bool_t          pmap_unset(unsigned long, unsigned long);
 extern struct pmaplist *pmap_getmaps(struct sockaddr_in *);
 #ifndef __LIBC12_SOURCE__
 extern enum clnt_stat  pmap_rmtcall(struct sockaddr_in *,
-                                       u_long, u_long, u_long,
+                                       unsigned long, unsigned long,
+                                       unsigned long,
                                        xdrproc_t, caddr_t,
                                        xdrproc_t, caddr_t,
-                                       struct timeval, u_long *)
+                                       struct timeval, unsigned long *)
                                        __RENAME(__pmap_rmtcall50);
 #endif
-extern enum clnt_stat  clnt_broadcast(u_long, u_long, u_long,
+extern enum clnt_stat  clnt_broadcast(unsigned long, unsigned long,
+                                       unsigned long,
                                        xdrproc_t, char *,
                                        xdrproc_t, char *,
                                        resultproc_t);
 extern u_short         pmap_getport(struct sockaddr_in *,
-                                       u_long, u_long, u_int);
+                                       unsigned long, unsigned long,
+                                       unsigned);
 __END_DECLS
 
 #endif /* !_RPC_PMAP_CLNT_H_ */
diff -r 749b9b187a21 -r e362645e337b include/rpc/rpc.h
--- a/include/rpc/rpc.h Sat Jan 23 00:43:42 2016 +0000
+++ b/include/rpc/rpc.h Sat Jan 23 01:05:30 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rpc.h,v 1.15 2006/06/22 19:35:34 christos Exp $        */
+/*     $NetBSD: rpc.h,v 1.16 2016/01/23 01:05:30 dholland Exp $        */
 



Home | Main Index | Thread Index | Old Index
diff -r 749b9b187a21 -r e362645e337b include/rpc/clnt.h
--- a/include/rpc/clnt.h        Sat Jan 23 00:43:42 2016 +0000
+++ b/include/rpc/clnt.h        Sat Jan 23 01:05:30 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: clnt.h,v 1.22 2014/06/06 14:31:24 christos Exp $       */
+/*     $NetBSD: clnt.h,v 1.23 2016/01/23 01:05:30 dholland Exp $       */
 
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
@@ -156,7 +156,7 @@
                /* destroy this structure */
                void            (*cl_destroy)(struct __rpc_client *);
                /* the ioctl() of rpc */
-               bool_t          (*cl_control)(struct __rpc_client *, u_int,
+               bool_t          (*cl_control)(struct __rpc_client *, unsigned,
                                    char *);
        } *cl_ops;
        void                    *cl_private;    /* private stuff */
@@ -169,9 +169,9 @@
  * Timers used for the pseudo-transport protocol when using datagrams
  */
 struct rpc_timers {
-       u_short         rt_srtt;        /* smoothed round-trip time */
-       u_short         rt_deviate;     /* estimated deviation */
-       u_long          rt_rtxcur;      /* current (backed-off) rto */
+       unsigned short  rt_srtt;        /* smoothed round-trip time */
+       unsigned short  rt_deviate;     /* estimated deviation */
+       unsigned long   rt_rtxcur;      /* current (backed-off) rto */
 };
 
 /*      
@@ -245,7 +245,7 @@
  * bool_t
  * CLNT_CONTROL(cl, request, info)
  *      CLIENT *cl;
- *      u_int request;
+ *      unsigned request;
  *      char *info;
  */
 #define        CLNT_CONTROL(cl,rq,in) ((*(cl)->cl_ops->cl_control)(cl,rq,in))
@@ -365,15 +365,16 @@
 
 extern CLIENT *clnt_tli_create(const int, const struct netconfig *,
                                    const struct netbuf *, const rpcprog_t,
-                                   const rpcvers_t, const u_int, const u_int);
+                                   const rpcvers_t, const unsigned,
+                                   const unsigned);
 /*
  *     const register int fd;          -- fd
  *     const struct netconfig *nconf;  -- netconfig structure
  *     const struct netbuf *svcaddr;           -- servers address
  *     const u_long prog;                      -- program number
  *     const u_long vers;                      -- version number
  *     const u_int sendsz;                     -- send size
  *     const u_int recvsz;                     -- recv size
  */
 
 /*
@@ -381,14 +382,14 @@
  */
 extern CLIENT *clnt_vc_create(const int, const struct netbuf *,
                                   const rpcprog_t, const rpcvers_t,
-                                  const u_int, const u_int);
+                                  const unsigned, const unsigned);
 /*
  *     const int fd;                           -- open file descriptor
  *     const struct netbuf *svcaddr;           -- servers address
  *     const rpcprog_t prog;                   -- program number
  *     const rpcvers_t vers;                   -- version number
  *     const u_int sendsz;                     -- buffer recv size
  *     const u_int recvsz;                     -- buffer send size
  */
 
 /*
@@ -396,22 +397,22 @@
  */
 extern CLIENT *clnt_dg_create(const int, const struct netbuf *,
                                   const rpcprog_t, const rpcvers_t,
-                                  const u_int, const u_int);
+                                  const unsigned, const unsigned);
 /*
  *     const int fd;                           -- open file descriptor
  *     const struct netbuf *svcaddr;           -- servers address
  *     const rpcprog_t program;                -- program number
  *     const rpcvers_t version;                -- version number
  *     const u_int sendsz;                     -- buffer recv size
  *     const u_int recvsz;                     -- buffer send size
  */
 
 /*
  * Memory based rpc (for speed check and testing)
  * CLIENT *
  * clnt_raw_create(prog, vers)
- *     u_long prog;
- *     u_long vers;
+ *     unsigned long prog;
+ *     unsigned long vers;
  */
 extern CLIENT *clnt_raw_create (rpcprog_t, rpcvers_t);
 
@@ -365,15 +365,16 @@
  *     const struct netconfig *nconf;  -- netconfig structure
  *     const struct netbuf *svcaddr;           -- servers address
- *     const u_long prog;                      -- program number
- *     const u_long vers;                      -- version number
- *     const u_int sendsz;                     -- send size
- *     const u_int recvsz;                     -- recv size
+ *     const unsigned long prog;               -- program number
+ *     const unsigned long vers;               -- version number
+ *     const unsigned sendsz;                  -- send size
+ *     const unsigned recvsz;                  -- recv size
  */
 
@@ -381,14 +382,14 @@
  *     const rpcprog_t prog;                   -- program number
  *     const rpcvers_t vers;                   -- version number
- *     const u_int sendsz;                     -- buffer recv size
- *     const u_int recvsz;                     -- buffer send size
+ *     const unsigned sendsz;                  -- buffer recv size
+ *     const unsigned recvsz;                  -- buffer send size
  */
 
@@ -396,22 +397,22 @@
  *     const rpcprog_t program;                -- program number
  *     const rpcvers_t version;                -- version number
- *     const u_int sendsz;                     -- buffer recv size
- *     const u_int recvsz;                     -- buffer send size
+ *     const unsigned sendsz;                  -- buffer recv size
+ *     const unsigned recvsz;                  -- buffer send size
  */
 